@@ -2,7 +2,7 @@ import os
 os.environ['ANSI_COLORS_DISABLED']="1"
 import shutil
 import fire
-from codemaker.makecode import gencode,write_yaml
+from codemaker.makecode import gencode,write_yaml,render
 DEFAULT_MAKER_FILENAME='maker.yaml'
 class CLI:
     def hi(cls):
@@ -20,7 +20,8 @@ class CLI:
         ),target)
     def gencode(self,src,dst,maker=DEFAULT_MAKER_FILENAME,overwrite=False,exists_ok=True,**kwargs):
         return gencode(src,dst,maker,overwrite=overwrite,exists_ok=exists_ok,**kwargs)
-
+    def render(self,path='.',maker=DEFAULT_MAKER_FILENAME,**kwargs):
+        return render(path,maker,**kwargs)
 def main():
     fire.Fire(CLI())
 
